position_to_day

Function position_to_day 

pub fn position_to_day(
    x: usize,
    y: usize,
    year: i32,
    month: u32,
) -> (usize, IsInMonth)
Panics

Calculates the day number at the given position in the calendar table based on the given year and month. panics if year, month or day does not exist.